#
# spec file for package python-fissix
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python3-%{**}}
%define skip_python2 1
Name:           python-fissix
Version:        24.4.24
Release:        1.2
Summary:        Backport of lib2to3, with enhancements
License:        Python-2.0
URL:            https://github.com/jreese/fissix
Source:         https://files.pythonhosted.org/packages/source/f/fissix/fissix-%{version}.tar.gz
BuildRequires:  %{python_module appdirs}
BuildRequires:  %{python_module base >= 3.6}
BuildRequires:  %{python_module flit-core >= 2}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest >= 6.0.1}
BuildRequires:  %{python_module testsuite}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-appdirs
BuildArch:      noarch
%python_subpackages

%description
Backport of latest lib2to3, with enhancements.

%prep
%setup -q -n fissix-%{version}
sed -i '1{/^#!/d}' fissix/pgen2/token.py fissix/tests/pytree_idempotency.py
chmod -x fissix/pgen2/token.py fissix/tests/pytree_idempotency.py
# remove tests with python2 syntax, because they fail to compile during pyproject_install
mv fissix/tests/data testdata

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
mv testdata fissix/tests/data
# ensure that pickled cache files don't interfere between flavors
%python_expand mkdir build/cache
export XDG_CACHE_HOME=$PWD/build/cache
%pytest

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/fissix
%{python_sitelib}/fissix-%{version}*-info

%changelog
* Sat Apr 27 2024 Dirk Müller <dmueller@suse.com>
- update to 24.4.24:
  * Maintenance release
  * Updated project metadata
  * Tested on Python 3.8 - 3.12
* Sat Dec 25 2021 Ben Greiner <code@bnavigator.de>
- Update to 21.11.13
  * Fix: except fixer checks against the value of a node (#42, #43)
  * Improved urllib fixer to include __version__ (#44)
  * Tested against Python 3.9 (#32, #45)
- Release 21.6.6
  * New fixer for sorted() and list.sort() (#25)
  * Token helpers for LBrace, RBrace, and Colon (#34)
  * Fix for long used as keyword argument name (#28)
  * Fix for exceptions with "as" keyword (#40)
  * Support for running tests outside of source tree (#31)
  * Documentation for fixers, general API, and usage (#23, #24,
    [#29])
- Fix caching interference between flavors
- Build with PEP517 flit-core.
* Fri Sep 18 2020 John Vandenberg <jayvdb@gmail.com>
- Activate test suite
- Update to 20.8.0
  * include dict in iterating context
  * Fixed reporting some unchanged files as needing modification
* Wed Jul  1 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 20.5.1:
  * No upstream changelog.
* Fri Sep 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Initial version, needed by dephell
